@@ -1,3 +1,7 @@
+#![warn(clippy::all, clippy::pedantic)]
+#![allow(clippy::too_many_lines)]
+#![allow(clippy::cast_possible_truncation)]
+#![allow(clippy::map_unwrap_or)]
 #![forbid(unsafe_code)]
 
 use std::collections::HashMap;
@@ -17,13 +21,14 @@ mod utils;
 #[cfg(test)]
 mod parse_test;
 
-fn construct_config(matches: clap::ArgMatches) -> Config {
+fn construct_config(matches: &clap::ArgMatches) -> Config {
     let interactive_terminal = atty::is(Stream::Stdout);
     let colored_output = match matches.value_of("color") {
         Some("always") => true,
         Some("never") => false,
         _ => env::var_os("NO_COLOR").is_none() && interactive_terminal,
     };
+    // enable colored output if set
     if colored_output {
         Paint::enable();
     } else {
@@ -43,7 +48,7 @@ fn construct_config(matches: clap::ArgMatches) -> Config {
         let regexps: Vec<&str> = matches.values_of("regexp").unwrap().collect();
         // assign a colour to each regexp
         for (i, regexp) in regexps.iter().enumerate() {
-            regexp_colours.insert(regexp.to_string(), colours[i % colours.len()]);
+            regexp_colours.insert((*regexp).to_string(), colours[i % colours.len()]);
         }
     }
 
@@ -62,26 +67,13 @@ fn construct_config(matches: clap::ArgMatches) -> Config {
             std::process::exit(1);
         }
     }
-    let mut level_symbols = false;
-    // if the env SNAZY_LEVEL_SYMBOLS is set, we use it to set the level symbols
-    if let Ok(level_symbols_env) = env::var("SNAZY_LEVEL_SYMBOLS") {
-        level_symbols = level_symbols_env.parse::<bool>().unwrap();
-    }
-    if matches.occurrences_of("level-symbols") > 0 {
-        level_symbols = true;
-    }
-
-    let mut kail_prefix_format = String::new();
-    if let Ok(kail_prefix_format_env) = env::var("SNAZY_KAIL_PREFIX_FORMAT") {
-        kail_prefix_format = kail_prefix_format_env.parse::<String>().unwrap();
-    }
-
-    if matches.occurrences_of("kail-prefix-format") > 0 {
-        kail_prefix_format = matches.value_of("kail-prefix-format").unwrap().to_string();
-    }
-
     Config {
-        kail_prefix_format,
+        kail_prefix_format: matches
+            .value_of("kail-prefix-format")
+            .map(String::from)
+            .or_else(|| env::var("SNAZY_KAIL_PREFIX_FORMAT").ok())
+            .and_then(|t| t.parse().ok())
+            .unwrap_or_default(),
         files: matches
             .values_of("files")
             .map(|v| v.map(String::from).collect())
@@ -91,10 +83,16 @@ fn construct_config(matches: clap::ArgMatches) -> Config {
             .values_of("filter-levels")
             .map(|v| v.map(String::from).collect())
             .unwrap_or_else(Vec::new),
-        time_format: matches.value_of("time_format").unwrap().to_string(),
+        time_format: matches
+            .value_of("time_format")
+            .map(String::from)
+            .or_else(|| env::var("SNAZY_TIME_FORMAT").ok())
+            .and_then(|t| t.parse().ok())
+            .unwrap_or_default(),
         regexp_colours,
         colored_output,
-        level_symbols,
+        level_symbols: matches.is_present("level-symbols")
+            || env::var("SNAZY_LEVEL_SYMBOLS").is_ok(),
         // split json keys by '=' and store in a key, value hashmap
         json_keys: matches
             .values_of("json-keys")
@@ -108,15 +106,59 @@ fn construct_config(matches: clap::ArgMatches) -> Config {
                 json_values
             })
             .unwrap_or_else(HashMap::new),
+        action_regexp: matches
+            .value_of("action-regexp")
+            .map(String::from)
+            .unwrap_or_default(),
+        action_command: matches
+            .value_of("action-command")
+            .map(String::from)
+            .unwrap_or_default(),
+    }
+}
+
+#[cfg(test)]
+mod tests {
+
+    use super::*;
+
+    #[test]
+    fn test_construct_config() {
+        let args = vec![
+            "snazy",
+            "--regexp",
+            "foo.*",
+            "--time-format",
+            "%S",
+            "-f",
+            "info",
+            "--json-keys",
+            "level=level",
+            "--json-keys",
+            "msg=msg",
+            "--json-keys",
+            "ts=ts",
+            "test.log",
+        ];
+
+        let matches = cli::build().get_matches_from(args);
+        let config = construct_config(&matches);
+        assert_eq!(config.files, vec!["test.log".to_string()]);
+        assert!(!config.kail_no_prefix);
+        assert_eq!(config.filter_levels, vec!["info".to_string()]);
+        assert_eq!(config.time_format, "%S".to_string());
+        assert_eq!(config.json_keys.len(), 3);
+        assert_eq!(config.action_regexp, "".to_string());
+        assert_eq!(config.action_command, "".to_string());
     }
 }
 
 fn main() {
-    let matches = cli::build_cli().get_matches_from(env::args_os());
-    let config = construct_config(matches);
+    let matches = cli::build().get_matches_from(env::args_os());
+    let config = construct_config(&matches);
     if config.files.is_empty() {
-        parse::read_from_stdin(Arc::new(config))
+        parse::read_from_stdin(&Arc::new(config));
     } else {
-        parse::read_from_files(Arc::new(config));
+        parse::read_from_files(&Arc::new(config));
     }
 }
