@@ -85,8 +85,8 @@ mod tests {
     #[test]
     fn test_config_json_keys() {
         let mut keys = HashMap::new();
-        keys.insert(String::from("foo"), String::from("msg"));
-        keys.insert(String::from("bar"), String::from("level"));
+        keys.insert(String::from("/foo"), String::from("msg"));
+        keys.insert(String::from("/bar"), String::from("level"));
 
         let config = Config {
             json_keys: keys,
@@ -101,7 +101,7 @@ mod tests {
     #[test]
     fn test_config_json_timestamp_float() {
         let mut keys = HashMap::new();
-        keys.insert(String::from("bar"), String::from("ts"));
+        keys.insert(String::from("/bar"), String::from("ts"));
 
         let config = Config {
             json_keys: keys,
@@ -115,9 +115,9 @@ mod tests {
     #[test]
     fn test_custom_json_match() {
         let mut keys = HashMap::new();
-        keys.insert(String::from("bar"), String::from("ts"));
-        keys.insert(String::from("foo"), String::from("msg"));
-        keys.insert(String::from("level"), String::from("level"));
+        keys.insert(String::from("/bar"), String::from("ts"));
+        keys.insert(String::from("/foo"), String::from("msg"));
+        keys.insert(String::from("/level"), String::from("level"));
 
         let config = Config {
             json_keys: keys,
@@ -174,7 +174,7 @@ mod tests {
         file.close().unwrap();
         assert_eq!(
             "\u{1b}[38;5;10mINFO\u{1b}[0m  \u{1b}[38;5;13m14:20:32\u{1b}[0m hello world\n\u{1b}[38;5;14mDEBUG\u{1b}[0m \u{1b}[38;5;13m14:20:32\u{1b}[0m debug\n",
-            std::str::from_utf8(&writeto).unwrap()
+            std::str::from_utf8(writeto).unwrap()
         );
     }
 }
